=============
Module - warn
=============


This module provides for the following ansible plugin:

    * warn


.. ansibleautoplugin::
   :module: validations_common/library/warn.py
   :documentation: true
   :examples: true
